/*
 * Copyright (c) 2005-2007 Extreme! Lab, Indiana University. All rights reserved.
 *
 * This software is open source. See the bottom of this file for the license.
 *
 * $Id: MyProxyLoader.java,v 1.5 2007/07/24 22:24:55 sshirasu Exp $
 */
package edu.indiana.extreme.xbaya.myproxy.gui;

import org.globus.myproxy.MyProxyException;

import xsul5.MLogger;
import edu.indiana.extreme.xbaya.XBayaEngine;
import edu.indiana.extreme.xbaya.gui.Cancelable;
import edu.indiana.extreme.xbaya.gui.ErrorMessages;
import edu.indiana.extreme.xbaya.gui.WaitDialog;
import edu.indiana.extreme.xbaya.myproxy.MyProxyClient;

/**
 * @author Satoshi Shirasuna
 */
public class MyProxyLoader implements Cancelable {

    private static final MLogger logger = MLogger.getLogger();

    private XBayaEngine engine;

    private Thread loadingThread;

    private boolean canceled;

    private WaitDialog waitDialog;

    /**
     * Constructs a MonitorStarter.
     * 
     * @param engine
     */
    public MyProxyLoader(XBayaEngine engine) {
        this.engine = engine;

        this.waitDialog = new WaitDialog(this, "Loading Proxy",
                "Loading a proxy.\n" + "Please wait for a moment.", this.engine);
    }

    /**
     * @see edu.indiana.extreme.xbaya.gui.Cancelable#cancel()
     */
    public void cancel() {
        this.canceled = true;
        this.loadingThread.interrupt();
    }

    /**
     * Loads myProxy.
     */
    public void load() {
        this.canceled = false;

        this.loadingThread = new Thread() {
            @Override
            public void run() {
                runInThread();
            }
        };
        this.loadingThread.start();

        // This has to be the last because it blocks when the dialog is modal.
        this.waitDialog.show();
    }

    private void runInThread() {
        try {
            MyProxyClient client = this.engine.getMyProxyClient();
            client.load();
            this.waitDialog.hide();
        } catch (MyProxyException e) {
            this.waitDialog.hide();
            if (this.canceled) {
                logger.caught(e);
            } else {
                String message = ErrorMessages.MYPROXY_LOAD_ERROR + "\n"
                        + e.getMessage();
                this.engine.getErrorWindow().error(message, e);
            }
        } catch (RuntimeException e) {
            this.waitDialog.hide();
            if (this.canceled) {
                logger.caught(e);
            } else {
                this.engine.getErrorWindow().error(
                        ErrorMessages.UNEXPECTED_ERROR, e);
            }
        } catch (Error e) {
            this.waitDialog.hide();
            this.engine.getErrorWindow().error(ErrorMessages.UNEXPECTED_ERROR,
                    e);
        }
    }
}

/*
 * Indiana University Extreme! Lab Software License, Version 1.2
 * 
 * Copyright (c) 2005-2007 The Trustees of Indiana University. All rights
 * reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 * 1) All redistributions of source code must retain the above copyright notice,
 * the list of authors in the original source code, this list of conditions and
 * the disclaimer listed in this license;
 * 
 * 2) All redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the disclaimer listed in this license in
 * the documentation and/or other materials provided with the distribution;
 * 
 * 3) Any documentation included with all redistributions must include the
 * following acknowledgement:
 * 
 * "This product includes software developed by the Indiana University Extreme!
 * Lab. For further information please visit http://www.extreme.indiana.edu/"
 * 
 * Alternatively, this acknowledgment may appear in the software itself, and
 * wherever such third-party acknowledgments normally appear.
 * 
 * 4) The name "Indiana University" or "Indiana University Extreme! Lab" shall
 * not be used to endorse or promote products derived from this software without
 * prior written permission from Indiana University. For written permission,
 * please contact http://www.extreme.indiana.edu/.
 * 
 * 5) Products derived from this software may not use "Indiana University" name
 * nor may "Indiana University" appear in their name, without prior written
 * permission of the Indiana University.
 * 
 * Indiana University provides no reassurances that the source code provided
 * does not infringe the patent or any other intellectual property rights of any
 * other entity. Indiana University disclaims any liability to any recipient for
 * claims brought by any other entity based on infringement of intellectual
 * property rights or otherwise.
 * 
 * LICENSEE UNDERSTANDS THAT SOFTWARE IS PROVIDED "AS IS" FOR WHICH NO
 * WARRANTIES AS TO CAPABILITIES OR ACCURACY ARE MADE. INDIANA UNIVERSITY GIVES
 * NO WARRANTIES AND MAKES NO REPRESENTATION THAT SOFTWARE IS FREE OF
 * INFRINGEMENT OF THIRD PARTY PATENT, COPYRIGHT, OR OTHER PROPRIETARY RIGHTS.
 * INDIANA UNIVERSITY MAKES NO WARRANTIES THAT SOFTWARE IS FREE FROM "BUGS",
 * "VIRUSES", "TROJAN HORSES", "TRAP DOORS", "WORMS", OR OTHER HARMFUL CODE.
 * LICENSEE ASSUMES THE ENTIRE RISK AS TO THE PERFORMANCE OF SOFTWARE AND/OR
 * ASSOCIATED MATERIALS, AND TO THE PERFORMANCE AND VALIDITY OF INFORMATION
 * GENERATED USING SOFTWARE.
 */
